import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'dyteMeeting.dart';

class DyteMeeting extends StatelessWidget {
  late String roomName;
  late String authToken;
  late bool showSetupScreen;
  late String apiBase;
  late String orgId;
  late bool autoTune;
  late Function onInit;

  DyteMeeting(
      {required String roomName,
      required String authToken,
      required Function onInit,
      String apiBase = "https://api.cluster.dyte.in",
      String orgId = "",
      bool autoTune = true,
      bool showSetupScreen = false}) {
    this.roomName = roomName;
    this.authToken = authToken;
    this.onInit = onInit;
    this.showSetupScreen = showSetupScreen;
    this.autoTune = autoTune;
    this.orgId = orgId;
    this.apiBase = apiBase; 
  }

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    final String viewType = 'dyte-meeting-view';
    // Pass parameters to the platform side.
    double originalDevicePixelRatio = MediaQuery.of(context).devicePixelRatio;
    Map<String, dynamic> creationParams = <String, dynamic>{};
    return LayoutBuilder(builder: (context, constraints) {
      creationParams = {
        'roomName': this.roomName,
        'authToken': this.authToken,
        'apiBase': this.apiBase,
        'showSetupScreen': this.showSetupScreen,
        'orgId': this.orgId,
        'autoTune': this.autoTune,
        'width': (originalDevicePixelRatio * constraints.maxWidth) ~/ 1,
        'height': (originalDevicePixelRatio * constraints.maxHeight) ~/ 1,
      };
      switch (defaultTargetPlatform) {
      case TargetPlatform.android:
        return PlatformViewLink(
          viewType: viewType,
          surfaceFactory:
              (BuildContext context, PlatformViewController controller) {
            return AndroidViewSurface(
              controller: controller as AndroidViewController,
              gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
              hitTestBehavior: PlatformViewHitTestBehavior.opaque,
            );
          },
          onCreatePlatformView: (PlatformViewCreationParams params) {
            this.onInit(new DyteMeetingHandler());
            return PlatformViewsService.initSurfaceAndroidView(
              id: params.id,
              viewType: viewType,
              layoutDirection: TextDirection.ltr,
              creationParams: {
                'roomName': this.roomName,
                'authToken': this.authToken,
                'apiBase': this.apiBase,
                'showSetupScreen': this.showSetupScreen,
                'orgId': this.orgId,
                'autoTune': this.autoTune,
                'width': (originalDevicePixelRatio * constraints.maxWidth) ~/ 1,
                'height': (originalDevicePixelRatio * constraints.maxHeight) ~/ 1,
              },
              creationParamsCodec: StandardMessageCodec(),
            )
              ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
              ..create();
          },
        );
        case TargetPlatform.iOS:
        return UiKitView(
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: {
              'roomName': this.roomName,
              'authToken': this.authToken,
              'apiBase': this.apiBase,
              'showSetupScreen': this.showSetupScreen,
              'orgId': this.orgId,
              'autoTune': this.autoTune,
              'width': constraints.maxWidth,
              'height': constraints.maxHeight
          },
          creationParamsCodec: const StandardMessageCodec(),
          onPlatformViewCreated: (int) {
            this.onInit(new DyteMeetingHandler());
          }
        );
      default:
        throw UnsupportedError("Unsupported platform view");
      }
    });
  }
}